@@ -15,9 +15,9 @@ for internal tests
 use strict;
 use warnings;
 no warnings qw(qw utf8);
-use v5.10;
-use open qw(:std :locale);
+use v5.14;
 use utf8;
+use open qw(:std :locale);
 use Config;
 use FindBin;
 use Data::Dumper;
@@ -29,13 +29,7 @@ use App::Virtualenv::Module;
 use App::Virtualenv::Piv;
 
 
-my $inst = ExtUtils::Installed->new;
-my @a = $inst->directory_tree("Net::Twitter", "all");
-say Dumper(\@a);
-exit;
-#exit App::Virtualenv::Module::install(force => 1, modules => ['ExtUtils::Installed']);
-#exit App::Virtualenv::Piv::main(@ARGV);
-#exit App::Virtualenv::perl("-I${FindBin::Bin}/../lib", "-MApp::Virtualenv::Module", "-e exit App::Virtualenv::Module::${ARGV[0]}('${ARGV[1]}');");
+exit 0;
 __END__
 =head1 AUTHOR
 
